module_version("ab2/6.12.3", "6.12")
module_version("ab2/6.12",   "6")

module_version("ab2/7.4.3",  "7.4")
module_version("ab2/7.4",    "7")

module_version("ab2/6",      "default")
module_version("ab2/7",      "default")

