local pkg = {}

pkg.display_name = "Python"
pkg.help = "http://hpc.uit.no/docs/software/python"
pkg.category = "Application"
pkg.keywords = ""
pkg.url = "http://www.python.org/"
pkg.license = ""
pkg.description = "Python with scientific packages"

return pkg
