local help_message = [[
This is a module file for the container quay.io/biocontainers/export2graphlan:0.19--py27_0, which exposes the
following programs:

 - assistant
 - createpackage
 - designer
 - elf2e32_qtwrapper
 - export2graphlan.py
 - findtr
 - lconvert
 - libpng15-config
 - linguist
 - lrelease
 - lupdate
 - moc
 - patch_capabilities
 - pixeltool
 - pylupdate4
 - pyrcc4
 - pyuic4
 - qcollectiongenerator
 - qhelpconverter
 - qhelpgenerator
 - qmake
 - qmlplugindump
 - qmlviewer
 - qtconfig
 - qttracereplay
 - rcc
 - sip
 - syncqt
 - uic
 - xmlpatterns
 - xmlpatternsvalidator

This container was pulled from:

	https://quay.io/repository/biocontainers/export2graphlan

If you encounter errors in export2graphlan or need help running the
tools it contains, please contact the developer at

	https://quay.io/repository/biocontainers/export2graphlan

For errors in the container or module file, please
submit a ticket at

	gzynda@tacc.utexas.edu
	https://portal.tacc.utexas.edu/tacc-consulting
]]
help(help_message,"\n")

whatis("Name: export2graphlan")
whatis("Version: ctr-0.19--py27_0")
whatis("Category: ['Bioinformatics']")
whatis("Keywords: ['Biocontainer']")
whatis("Description: The export2graphlan package")
whatis("URL: https://quay.io/repository/biocontainers/export2graphlan")

set_shell_function("assistant",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg assistant $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg assistant $*')
set_shell_function("createpackage",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg createpackage $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg createpackage $*')
set_shell_function("designer",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg designer $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg designer $*')
set_shell_function("elf2e32_qtwrapper",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg elf2e32_qtwrapper $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg elf2e32_qtwrapper $*')
set_shell_function("export2graphlan.py",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg export2graphlan.py $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg export2graphlan.py $*')
set_shell_function("findtr",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg findtr $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg findtr $*')
set_shell_function("lconvert",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg lconvert $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg lconvert $*')
set_shell_function("libpng15-config",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg libpng15-config $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg libpng15-config $*')
set_shell_function("linguist",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg linguist $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg linguist $*')
set_shell_function("lrelease",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg lrelease $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg lrelease $*')
set_shell_function("lupdate",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg lupdate $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg lupdate $*')
set_shell_function("moc",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg moc $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg moc $*')
set_shell_function("patch_capabilities",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg patch_capabilities $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg patch_capabilities $*')
set_shell_function("pixeltool",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg pixeltool $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg pixeltool $*')
set_shell_function("pylupdate4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg pylupdate4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg pylupdate4 $*')
set_shell_function("pyrcc4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg pyrcc4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg pyrcc4 $*')
set_shell_function("pyuic4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg pyuic4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg pyuic4 $*')
set_shell_function("qcollectiongenerator",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qcollectiongenerator $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qcollectiongenerator $*')
set_shell_function("qhelpconverter",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qhelpconverter $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qhelpconverter $*')
set_shell_function("qhelpgenerator",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qhelpgenerator $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qhelpgenerator $*')
set_shell_function("qmake",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qmake $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qmake $*')
set_shell_function("qmlplugindump",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qmlplugindump $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qmlplugindump $*')
set_shell_function("qmlviewer",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qmlviewer $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qmlviewer $*')
set_shell_function("qtconfig",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qtconfig $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qtconfig $*')
set_shell_function("qttracereplay",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qttracereplay $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg qttracereplay $*')
set_shell_function("rcc",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg rcc $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg rcc $*')
set_shell_function("sip",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg sip $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg sip $*')
set_shell_function("syncqt",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg syncqt $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg syncqt $*')
set_shell_function("uic",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg uic $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg uic $*')
set_shell_function("xmlpatterns",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg xmlpatterns $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg xmlpatterns $*')
set_shell_function("xmlpatternsvalidator",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg xmlpatternsvalidator $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/export2graphlan/export2graphlan-0.19--py27_0.simg xmlpatternsvalidator $*')
