local mroot = os.getenv("MODULEPATH_ROOT")
whatis([[Intel MPI]])
whatis([[Version: 4.1]])
whatis([[Category: library, runtime support]])
whatis([[Keywords: System, Library]])
whatis([[Description: MPI-2 implementation for Infiniband]])
setenv("MPICH_HOME","/unknown/apps/intel13/impi/4.1")
setenv("TACC_MPI_GETMODE","impi_ssh")
prepend_path("PATH","/unknown/apps/intel13/impi/4.1/bin")
prepend_path("MANPATH","/unknown/apps/intel13/impi/4.1/man")
prepend_path("INFOPATH","/unknown/apps/intel13/impi/4.1/doc")
prepend_path("LD_LIBRARY_PATH","/unknown/apps/intel13/impi/4.1/lib/shared")
prepend_path("LD_LIBRARY_PATH","/unknown/apps/intel13/impi/4.1/lib")
prepend_path("PKG_CONFIG_PATH","/unknown/apps/intel13/impi/4.1/lib/pkgconfig")
family("MPI")

prepend_path("MODULEPATH",pathJoin(mroot,"MPI","intel","13.0","impi","4.1"))
