local help_message = [[
This is a module file for the container biocontainers/edfbrowser:v1.58-1b1-deb_cv1, which exposes the
following programs:

 - assistant
 - designer
 - edfbrowser
 - lconvert
 - linguist
 - lrelease
 - lupdate
 - moc
 - pixeltool
 - qcollectiongenerator
 - qdbus
 - qdbuscpp2xml
 - qdbusviewer
 - qdbusxml2cpp
 - qdoc
 - qdoc3
 - qhelpconverter
 - qhelpgenerator
 - qlalr
 - qmake
 - qml
 - qml1plugindump
 - qmlbundle
 - qmleasing
 - qmlimportscanner
 - qmllint
 - qmlmin
 - qmlplugindump
 - qmlprofiler
 - qmlscene
 - qmltestrunner
 - qmlviewer
 - qtchooser
 - qtconfig
 - qtdiag
 - qtpaths
 - qtplugininfo
 - rcc
 - uic
 - uic3
 - xmlpatterns
 - xmlpatternsvalidator

This container was pulled from:

	https://hub.docker.com/r/biocontainers/edfbrowser

If you encounter errors in edfbrowser or need help running the
tools it contains, please contact the developer at

	https://hub.docker.com/r/biocontainers/edfbrowser

For errors in the container or module file, please
submit a ticket at

	gzynda@tacc.utexas.edu
	https://portal.tacc.utexas.edu/tacc-consulting
]]
help(help_message,"\n")

whatis("Name: edfbrowser")
whatis("Version: ctr-v1.58-1b1-deb_cv1")
whatis("Category: ['Bioinformatics']")
whatis("Keywords: ['Biocontainer']")
whatis("Description: The edfbrowser package")
whatis("URL: https://hub.docker.com/r/biocontainers/edfbrowser")

set_shell_function("assistant",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg assistant $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg assistant $*')
set_shell_function("designer",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg designer $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg designer $*')
set_shell_function("edfbrowser",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg edfbrowser $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg edfbrowser $*')
set_shell_function("lconvert",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg lconvert $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg lconvert $*')
set_shell_function("linguist",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg linguist $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg linguist $*')
set_shell_function("lrelease",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg lrelease $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg lrelease $*')
set_shell_function("lupdate",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg lupdate $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg lupdate $*')
set_shell_function("moc",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg moc $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg moc $*')
set_shell_function("pixeltool",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg pixeltool $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg pixeltool $*')
set_shell_function("qcollectiongenerator",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qcollectiongenerator $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qcollectiongenerator $*')
set_shell_function("qdbus",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qdbus $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qdbus $*')
set_shell_function("qdbuscpp2xml",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qdbuscpp2xml $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qdbuscpp2xml $*')
set_shell_function("qdbusviewer",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qdbusviewer $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qdbusviewer $*')
set_shell_function("qdbusxml2cpp",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qdbusxml2cpp $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qdbusxml2cpp $*')
set_shell_function("qdoc",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qdoc $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qdoc $*')
set_shell_function("qdoc3",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qdoc3 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qdoc3 $*')
set_shell_function("qhelpconverter",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qhelpconverter $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qhelpconverter $*')
set_shell_function("qhelpgenerator",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qhelpgenerator $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qhelpgenerator $*')
set_shell_function("qlalr",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qlalr $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qlalr $*')
set_shell_function("qmake",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmake $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmake $*')
set_shell_function("qml",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qml $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qml $*')
set_shell_function("qml1plugindump",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qml1plugindump $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qml1plugindump $*')
set_shell_function("qmlbundle",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmlbundle $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmlbundle $*')
set_shell_function("qmleasing",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmleasing $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmleasing $*')
set_shell_function("qmlimportscanner",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmlimportscanner $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmlimportscanner $*')
set_shell_function("qmllint",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmllint $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmllint $*')
set_shell_function("qmlmin",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmlmin $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmlmin $*')
set_shell_function("qmlplugindump",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmlplugindump $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmlplugindump $*')
set_shell_function("qmlprofiler",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmlprofiler $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmlprofiler $*')
set_shell_function("qmlscene",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmlscene $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmlscene $*')
set_shell_function("qmltestrunner",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmltestrunner $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmltestrunner $*')
set_shell_function("qmlviewer",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmlviewer $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qmlviewer $*')
set_shell_function("qtchooser",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qtchooser $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qtchooser $*')
set_shell_function("qtconfig",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qtconfig $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qtconfig $*')
set_shell_function("qtdiag",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qtdiag $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qtdiag $*')
set_shell_function("qtpaths",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qtpaths $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qtpaths $*')
set_shell_function("qtplugininfo",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qtplugininfo $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg qtplugininfo $*')
set_shell_function("rcc",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg rcc $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg rcc $*')
set_shell_function("uic",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg uic $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg uic $*')
set_shell_function("uic3",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg uic3 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg uic3 $*')
set_shell_function("xmlpatterns",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg xmlpatterns $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg xmlpatterns $*')
set_shell_function("xmlpatternsvalidator",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg xmlpatternsvalidator $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/edfbrowser/edfbrowser-v1.58-1b1-deb_cv1.simg xmlpatternsvalidator $*')
