local help_message = [[
This is a module file for the container quay.io/biocontainers/ete2:2.3.10--py27_1, which exposes the
following programs:

 - assistant-qt4
 - designer-qt4
 - ete
 - lconvert-qt4
 - linguist-qt4
 - lrelease-qt4
 - lupdate-qt4
 - moc-qt4
 - pixeltool-qt4
 - pylupdate4
 - pyrcc4
 - pyuic4
 - qcollectiongenerator-qt4
 - qdbus-qt4
 - qdbuscpp2xml-qt4
 - qdbusviewer-qt4
 - qdbusxml2cpp-qt4
 - qdoc3-qt4
 - qhelpconverter-qt4
 - qhelpgenerator-qt4
 - qmake-qt4
 - qmlplugindump-qt4
 - qmlviewer-qt4
 - qt3to4-qt4
 - qtconfig-qt4
 - qttracereplay-qt4
 - rcc-qt4
 - sip
 - uic-qt4
 - xmlpatterns-qt4
 - xmlpatternsvalidator-qt4
 - xslt-config
 - xsltproc

This container was pulled from:

	https://quay.io/repository/biocontainers/ete2

If you encounter errors in ete2 or need help running the
tools it contains, please contact the developer at

	https://quay.io/repository/biocontainers/ete2

For errors in the container or module file, please
submit a ticket at

	gzynda@tacc.utexas.edu
	https://portal.tacc.utexas.edu/tacc-consulting
]]
help(help_message,"\n")

whatis("Name: ete2")
whatis("Version: ctr-2.3.10--py27_1")
whatis("Category: ['Bioinformatics']")
whatis("Keywords: ['Biocontainer']")
whatis("Description: The ete2 package")
whatis("URL: https://quay.io/repository/biocontainers/ete2")

set_shell_function("assistant-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg assistant-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg assistant-qt4 $*')
set_shell_function("designer-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg designer-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg designer-qt4 $*')
set_shell_function("ete",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg ete $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg ete $*')
set_shell_function("lconvert-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg lconvert-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg lconvert-qt4 $*')
set_shell_function("linguist-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg linguist-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg linguist-qt4 $*')
set_shell_function("lrelease-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg lrelease-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg lrelease-qt4 $*')
set_shell_function("lupdate-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg lupdate-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg lupdate-qt4 $*')
set_shell_function("moc-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg moc-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg moc-qt4 $*')
set_shell_function("pixeltool-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg pixeltool-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg pixeltool-qt4 $*')
set_shell_function("pylupdate4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg pylupdate4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg pylupdate4 $*')
set_shell_function("pyrcc4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg pyrcc4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg pyrcc4 $*')
set_shell_function("pyuic4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg pyuic4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg pyuic4 $*')
set_shell_function("qcollectiongenerator-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qcollectiongenerator-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qcollectiongenerator-qt4 $*')
set_shell_function("qdbus-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qdbus-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qdbus-qt4 $*')
set_shell_function("qdbuscpp2xml-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qdbuscpp2xml-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qdbuscpp2xml-qt4 $*')
set_shell_function("qdbusviewer-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qdbusviewer-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qdbusviewer-qt4 $*')
set_shell_function("qdbusxml2cpp-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qdbusxml2cpp-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qdbusxml2cpp-qt4 $*')
set_shell_function("qdoc3-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qdoc3-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qdoc3-qt4 $*')
set_shell_function("qhelpconverter-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qhelpconverter-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qhelpconverter-qt4 $*')
set_shell_function("qhelpgenerator-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qhelpgenerator-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qhelpgenerator-qt4 $*')
set_shell_function("qmake-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qmake-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qmake-qt4 $*')
set_shell_function("qmlplugindump-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qmlplugindump-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qmlplugindump-qt4 $*')
set_shell_function("qmlviewer-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qmlviewer-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qmlviewer-qt4 $*')
set_shell_function("qt3to4-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qt3to4-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qt3to4-qt4 $*')
set_shell_function("qtconfig-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qtconfig-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qtconfig-qt4 $*')
set_shell_function("qttracereplay-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qttracereplay-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg qttracereplay-qt4 $*')
set_shell_function("rcc-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg rcc-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg rcc-qt4 $*')
set_shell_function("sip",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg sip $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg sip $*')
set_shell_function("uic-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg uic-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg uic-qt4 $*')
set_shell_function("xmlpatterns-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg xmlpatterns-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg xmlpatterns-qt4 $*')
set_shell_function("xmlpatternsvalidator-qt4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg xmlpatternsvalidator-qt4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg xmlpatternsvalidator-qt4 $*')
set_shell_function("xslt-config",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg xslt-config $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg xslt-config $*')
set_shell_function("xsltproc",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg xsltproc $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete2/ete2-2.3.10--py27_1.simg xsltproc $*')
