-- -*- lua -*-
-- vim:ft=lua:et:ts=4
--
local pkg = {}

pkg.display_name = "GNU Compilers"
pkg.help = "http://hpc.uit.no/docs/software/gcc"
pkg.category = "development"
pkg.keywords = "compiler"
pkg.url = "http://gcc.gnu.org/"
pkg.license = "GPL"
pkg.description = "GNU compiler suite"

return pkg
