help([==[

HELP Description
================
GROMACS(GPU/2019) is a versatile package to perform molecular dynamics,
 i.e. simulate the Newtonian equations of motion for systems with hundreds to millions of particles.

This is a GPU only build, containing both MPI and threadMPI builds for 2019.


More information
================
 - Homepage: http://www.gromacs.org
]==])

whatis([==[Description: 
GROMACS(GPU/2019) is a versatile package to perform molecular dynamics,
 i.e. simulate the Newtonian equations of motion for systems with hundreds to millions of particles.

This is a GPU only build, containing both MPI and threadMPI builds for 2019.
]==])
