local help_message = [[
This is a module file for the container quay.io/biocontainers/ecmwfapi:1.4.1--py27_0, which exposes the
following programs:

None - please invoke manually

This container was pulled from:

	https://quay.io/repository/biocontainers/ecmwfapi

If you encounter errors in ecmwfapi or need help running the
tools it contains, please contact the developer at

	https://quay.io/repository/biocontainers/ecmwfapi

For errors in the container or module file, please
submit a ticket at

	gzynda@tacc.utexas.edu
	https://portal.tacc.utexas.edu/tacc-consulting
]]
help(help_message,"\n")

whatis("Name: ecmwfapi")
whatis("Version: ctr-1.4.1--py27_0")
whatis("Category: ['Bioinformatics']")
whatis("Keywords: ['Biocontainer']")
whatis("Description: The ecmwfapi package")
whatis("URL: https://quay.io/repository/biocontainers/ecmwfapi")

