append_path("NCAR_LIB_INTEL", "-L/opt/netcdf/3.6.3/intel/12.1.0/lib"," ")
append_path("NCAR_LIB_INTEL", "-lnetcdf -lnetcdff"," ")
append_path("NCAR_LIB_INTEL", "-Wl,-rpath,/opt/netcdf/3.6.3/intel/12.1.0/lib"," ")
