local help_message = [[
This is a module file for the container quay.io/biocontainers/ete3:3.0.0b35--py36_1, which exposes the
following programs:

 - assistant
 - designer
 - easy_install-3.6
 - ete3
 - lconvert
 - linguist
 - lrelease
 - lupdate
 - moc
 - pixeltool
 - pylupdate4
 - pyrcc4
 - pyuic4
 - qcollectiongenerator
 - qdbus
 - qdbuscpp2xml
 - qdbusviewer
 - qdbusxml2cpp
 - qdoc3
 - qhelpconverter
 - qhelpgenerator
 - qmake
 - qmlplugindump
 - qmlviewer
 - qt3to4
 - qtconfig
 - qttracereplay
 - rcc
 - sip
 - uic
 - xmlpatterns
 - xmlpatternsvalidator
 - xslt-config
 - xsltproc

This container was pulled from:

	https://quay.io/repository/biocontainers/ete3

If you encounter errors in ete3 or need help running the
tools it contains, please contact the developer at

	https://quay.io/repository/biocontainers/ete3

For errors in the container or module file, please
submit a ticket at

	gzynda@tacc.utexas.edu
	https://portal.tacc.utexas.edu/tacc-consulting
]]
help(help_message,"\n")

whatis("Name: ete3")
whatis("Version: ctr-3.0.0b35--py36_1")
whatis("Category: ['Bioinformatics']")
whatis("Keywords: ['Biocontainer']")
whatis("Description: The ete3 package")
whatis("URL: https://quay.io/repository/biocontainers/ete3")

set_shell_function("assistant",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg assistant $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg assistant $*')
set_shell_function("designer",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg designer $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg designer $*')
set_shell_function("easy_install-3.6",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg easy_install-3.6 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg easy_install-3.6 $*')
set_shell_function("ete3",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg ete3 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg ete3 $*')
set_shell_function("lconvert",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg lconvert $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg lconvert $*')
set_shell_function("linguist",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg linguist $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg linguist $*')
set_shell_function("lrelease",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg lrelease $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg lrelease $*')
set_shell_function("lupdate",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg lupdate $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg lupdate $*')
set_shell_function("moc",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg moc $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg moc $*')
set_shell_function("pixeltool",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg pixeltool $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg pixeltool $*')
set_shell_function("pylupdate4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg pylupdate4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg pylupdate4 $*')
set_shell_function("pyrcc4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg pyrcc4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg pyrcc4 $*')
set_shell_function("pyuic4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg pyuic4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg pyuic4 $*')
set_shell_function("qcollectiongenerator",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qcollectiongenerator $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qcollectiongenerator $*')
set_shell_function("qdbus",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qdbus $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qdbus $*')
set_shell_function("qdbuscpp2xml",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qdbuscpp2xml $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qdbuscpp2xml $*')
set_shell_function("qdbusviewer",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qdbusviewer $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qdbusviewer $*')
set_shell_function("qdbusxml2cpp",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qdbusxml2cpp $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qdbusxml2cpp $*')
set_shell_function("qdoc3",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qdoc3 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qdoc3 $*')
set_shell_function("qhelpconverter",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qhelpconverter $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qhelpconverter $*')
set_shell_function("qhelpgenerator",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qhelpgenerator $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qhelpgenerator $*')
set_shell_function("qmake",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qmake $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qmake $*')
set_shell_function("qmlplugindump",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qmlplugindump $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qmlplugindump $*')
set_shell_function("qmlviewer",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qmlviewer $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qmlviewer $*')
set_shell_function("qt3to4",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qt3to4 $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qt3to4 $*')
set_shell_function("qtconfig",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qtconfig $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qtconfig $*')
set_shell_function("qttracereplay",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qttracereplay $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg qttracereplay $*')
set_shell_function("rcc",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg rcc $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg rcc $*')
set_shell_function("sip",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg sip $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg sip $*')
set_shell_function("uic",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg uic $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg uic $*')
set_shell_function("xmlpatterns",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg xmlpatterns $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg xmlpatterns $*')
set_shell_function("xmlpatternsvalidator",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg xmlpatternsvalidator $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg xmlpatternsvalidator $*')
set_shell_function("xslt-config",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg xslt-config $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg xslt-config $*')
set_shell_function("xsltproc",'singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg xsltproc $@','singularity exec ${BIOCONTAINER_DIR}/biocontainers/ete3/ete3-3.0.0b35--py36_1.simg xsltproc $*')
