-- Custom strings for SISC-HPC
-- Ward Poelmans <ward.poelmans@vub.ac.be>

return {
   en = {
     sisc_deprecated_module = "The module %{fullName} is outdated. Please use a version from %{tcver_cutoff} or newer.\nIf there is no newer version, request one at hpc@vub.ac.be.\n",
   }
}
