local mroot = os.getenv("MODULEPATH_ROOT")
whatis([[Name: Intel Compiler]])
whatis([[Version: 13.0]])
whatis([[Category: compiler, runtime support]])
whatis([[Description: Intel Compiler Family (C/C++/Fortran for x86_64)]])
whatis([[URL: http://software.intel.com/en-us/articles/intel-compilers/]])
prepend_path("PATH","/opt/intel/sep/bin")
prepend_path("PATH","/unknown/apps/intel/13/vtune_amplifier_xe_2013/bin64:/unknown/apps/intel/13/composer_xe_2013.2.146/bin/intel64:/unknown/apps/intel/13/composer_xe_2013.2.146/mpirt/bin/intel64")
append_path("PATH","/unknown/apps/intel/13/composer_xe_2013.2.146/bin/intel64:/unknown/apps/intel/13/composer_xe_2013.2.146/bin/intel64_mic:/unknown/apps/intel/13/composer_xe_2013.2.146/debugger/gui/intel64")
prepend_path("INCLUDE","/unknown/apps/intel/13/composer_xe_2013.2.146/ipp/include:/unknown/apps/intel/13/composer_xe_2013.2.146/mkl/include")
prepend_path("MANPATH","/unknown/apps/intel/13/composer_xe_2013.2.146/man/en_US:/unknown/apps/intel/13/composer_xe_2013.2.146/man/en_US:/unknown/apps/intel/13/vtune_amplifier_xe_2013/man")
--prepend_path("MODULEPATH","/unknown/apps/intel13/modulefiles")
prepend_path("MODULEPATH",pathJoin(mroot,"Compiler","intel","13.0"))

prepend_path("MIC_LD_LIBRARY_PATH","/unknown/apps/intel/13/composer_xe_2013.2.146/tbb/lib/mic:/unknown/apps/intel/13/composer_xe_2013.2.146/compiler/lib/mic:/opt/intel/mic/coi/device-linux-release/lib:/opt/intel/mic/myo/lib:/unknown/apps/intel/13/composer_xe_2013.2.146/tbb/lib/mic")
prepend_path("TBBROOT","/unknown/apps/intel/13/composer_xe_2013.2.146/tbb")
prepend_path("IPPROOT","/unknown/apps/intel/13/composer_xe_2013.2.146/ipp")
prepend_path("MKLROOT","/unknown/apps/intel/13/composer_xe_2013.2.146/mkl")
setenv("TACC_MKL_DIR","/unknown/apps/intel/13/composer_xe_2013.2.146/mkl")
setenv("TACC_MKL_INC","/unknown/apps/intel/13/composer_xe_2013.2.146/mkl/include")
setenv("TACC_MKL_LIB","/unknown/apps/intel/13/composer_xe_2013.2.146/mkl/lib/intel64")
prepend_path("LD_LIBRARY_PATH","/unknown/apps/intel/13/composer_xe_2013.2.146/tbb/lib/intel64:/unknown/apps/intel/13/composer_xe_2013.2.146/compiler/lib/intel64:/opt/intel/mic/coi/host-linux-release/lib:/opt/intel/mic/myo/lib:/unknown/apps/intel/13/composer_xe_2013.2.146/mpirt/lib/intel64:/unknown/apps/intel/13/composer_xe_2013.2.146/ipp/../compiler/lib/intel64:/unknown/apps/intel/13/composer_xe_2013.2.146/ipp/lib/intel64:/unknown/apps/intel/13/composer_xe_2013.2.146/compiler/lib/intel64:/unknown/apps/intel/13/composer_xe_2013.2.146/mkl/lib/intel64:/unknown/apps/intel/13/composer_xe_2013.2.146/tbb/lib/intel64")
prepend_path("SINK_LD_LIBRARY_PATH","/unknown/apps/intel/13/composer_xe_2013.2.146/compiler/lib/mic:/unknown/apps/intel/13/composer_xe_2013.2.146/mkl/lib/mic")
setenv("ICC_BIN","/unknown/apps/intel/13/composer_xe_2013.2.146/bin/intel64")
setenv("ICC_LIB","/unknown/apps/intel/13/composer_xe_2013.2.146/compiler/lib/intel64")
setenv("IFC_BIN","/unknown/apps/intel/13/composer_xe_2013.2.146/bin/intel64")
setenv("IFC_LIB","/unknown/apps/intel/13/composer_xe_2013.2.146/compiler/lib/intel64")
setenv("IIDB_BIN","/unknown/apps/intel/13/composer_xe_2013.2.146/bin/intel64")
setenv("MIC_ENV_PREFIX","MIC")
family("compiler")
