local mroot = os.getenv("MODULEPATH_ROOT")
whatis([[MVAPICH2]])
whatis([[Version: 1.9a2]])
whatis([[Category: library, runtime support]])
whatis([[Keywords: System, Library]])
whatis([[Description: MPI-2 implementation for Infiniband]])
whatis([[URL: http://mvapich.cse.ohio-state.edu/overview/mvapich2/]])
setenv("MPICH_HOME","/unknown/apps/intel13/mvapich2/1.9")
setenv("TACC_MPI_GETMODE","mvapich2_ssh")
prepend_path("PATH","/unknown/apps/intel13/mvapich2/1.9/bin")
prepend_path("MANPATH","/unknown/apps/intel13/mvapich2/1.9/man")
prepend_path("INFOPATH","/unknown/apps/intel13/mvapich2/1.9/doc")
prepend_path("LD_LIBRARY_PATH","/unknown/apps/intel13/mvapich2/1.9/lib/shared")
prepend_path("LD_LIBRARY_PATH","/unknown/apps/intel13/mvapich2/1.9/lib")
prepend_path("PKG_CONFIG_PATH","/unknown/apps/intel13/mvapich2/1.9/lib/pkgconfig")
family("MPI")

prepend_path("MODULEPATH",pathJoin(mroot,"MPI","intel","13.0","mvapich2","1.9"))
