help([==[

HELP Description
================
GROMACS(CPU/2018) is a versatile package to perform molecular dynamics,
 i.e. simulate the Newtonian equations of motion for systems with hundreds to millions of particles.

This is a CPU enabled build, containing both MPI and threadMPI binaries for 2018.


More information
================
 - Homepage: http://www.gromacs.org
]==])

whatis([==[Description: 
GROMACS(CPU/2018) is a versatile package to perform molecular dynamics,
 i.e. simulate the Newtonian equations of motion for systems with hundreds to millions of particles.

This is a CPU enabled build, containing both MPI and threadMPI binaries for 2018.
]==])
